summaryrefslogtreecommitdiffstats
path: root/client
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2016-04-08 03:06:39 +0200
committerSlávek Banko <slavek.banko@axis.cz>2016-04-08 03:06:39 +0200
commit96603e8acb744f86139b900e45d030ad684b6a4d (patch)
treebc983a53582ffe8f32e3fa9320eff557f239ea01 /client
parent5d3112684ba2b692a07b0328ad308c402276e51e (diff)
downloadtde-style-domino-96603e8acb744f86139b900e45d030ad684b6a4d.tar.gz
tde-style-domino-96603e8acb744f86139b900e45d030ad684b6a4d.zip
Initial TQt conversion
Signed-off-by: Slávek Banko <slavek.banko@axis.cz>
Diffstat (limited to 'client')
-rw-r--r--client/clientData.h54
-rw-r--r--client/config/config.cpp102
-rw-r--r--client/config/config.h26
-rw-r--r--client/dominoclient.cpp446
-rw-r--r--client/dominoclient.h74
5 files changed, 351 insertions, 351 deletions
diff --git a/client/clientData.h b/client/clientData.h
index d777214..306e55c 100644
--- a/client/clientData.h
+++ b/client/clientData.h
@@ -18,20 +18,20 @@
#ifndef _QEMBED_CLIENTDATA
#define _QEMBED_CLIENTDATA
-#include <qimage.h>
-#include <qdict.h>
-static const QRgb client_bottom_lines_dark_data[] = {
+#include <tqimage.h>
+#include <tqdict.h>
+static const TQRgb client_bottom_lines_dark_data[] = {
0x18000000,0x18000000,0x18000000,0x18000000,0x18000000,0x18000000,0x18000000,0x18000000,0x18000000,0x18000000,0x44000000,0x44000000,0x44000000,0x44000000,
0x44000000,0x44000000,0x44000000,0x44000000,0x44000000,0x44000000
};
/* Generated by qembed */
-static const QRgb client_bottomLines_data[] = {
+static const TQRgb client_bottomLines_data[] = {
0x6000000,0x6000000,0x6000000,0x6000000,0x6000000,0x6000000,0x6000000,0x6000000,0x6000000,0x6000000,0x13000000,0x13000000,0x13000000,0x13000000,
0x13000000,0x13000000,0x13000000,0x13000000,0x13000000,0x13000000
};
-static const QRgb clientButtonContour_data[] = {
+static const TQRgb clientButtonContour_data[] = {
0x0,0x0,0x0,0x0,0x2000000,0x9000000,0xe000000,0xf000000,0xf000000,0xe000000,0x9000000,0x2000000,0x0,0x0,
0x0,0x0,0x0,0x0,0x1000000,0x7000000,0x27000000,0x8c000000,0xc4000000,0xc9000000,0xc9000000,0xc4000000,0x8c000000,0x27000000,
0x7000000,0x1000000,0x0,0x0,0x0,0x0,0xa000000,0x64000000,0xca000000,0x6a000000,0x1b000000,0xf000000,0xf000000,0x1b000000,
@@ -53,7 +53,7 @@ static const QRgb clientButtonContour_data[] = {
0x0,0x0,0x0,0x0
};
-static const QRgb clientButtonPressed_data[] = {
+static const TQRgb clientButtonPressed_data[] = {
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xb151515,0x400b0b0b,0x420d0d0d,0x420d0d0d,0x41090909,0xb151515,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1000000,0x39131313,0x6d010101,0x68000000,0x62000000,0x62000000,0x67000000,
@@ -75,7 +75,7 @@ static const QRgb clientButtonPressed_data[] = {
0x0,0x0,0x0,0x0
};
-static const QRgb clientButtonShadow_data[] = {
+static const TQRgb clientButtonShadow_data[] = {
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x16fdfdfd,0x52fdfdfd,0x6ffdfdfd,0x6ffdfdfd,0x50fdfdfd,0x16fdfdfd,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xafdfdfd,0x7bfcfcfc,0x78fdfdfd,0x65ffffff,0x6ffdfdfd,0x6ffdfdfd,0x65ffffff,
@@ -97,18 +97,18 @@ static const QRgb clientButtonShadow_data[] = {
0x3ffffff,0x0,0x0,0x0
};
-static const QRgb client_close_6x6_data[] = {
+static const TQRgb client_close_6x6_data[] = {
0x6c2a2a2a,0x6b2a2a2a,0x0,0x0,0x6b2a2a2a,0x702a2a2a,0x7b2a2a2a,0xd62a2a2a,0x5c2a2a2a,0x792a2a2a,0xd62a2a2a,0x782a2a2a,0x0,0x7b2a2a2a,
0xd62a2a2a,0xd62a2a2a,0x782a2a2a,0x0,0x0,0x7b2a2a2a,0xd62a2a2a,0xd62a2a2a,0x782a2a2a,0x0,0x7b2a2a2a,0xd62a2a2a,0x782a2a2a,0x5e2a2a2a,
0xd62a2a2a,0x782a2a2a,0x6c2a2a2a,0x782a2a2a,0x0,0x0,0x5e2a2a2a,0x6c2a2a2a
};
-static const QRgb client_dot_4x4_data[] = {
+static const TQRgb client_dot_4x4_data[] = {
0x422a2a2a,0x9b2a2a2a,0x9b2a2a2a,0x422a2a2a,0x9b2a2a2a,0xb02a2a2a,0xb02a2a2a,0x9b2a2a2a,0x9b2a2a2a,0xb02a2a2a,0xb02a2a2a,0x9b2a2a2a,0x422a2a2a,0x9b2a2a2a,
0x9b2a2a2a,0x422a2a2a
};
-static const QRgb client_edges_dark_data[] = {
+static const TQRgb client_edges_dark_data[] = {
0x0,0x0,0x0,0x34000000,0x35000000,0x35000000,0x34000000,0x0,0x0,0x0,0x0,0x0,0x34000000,0x2b000000,
0xe000000,0xe000000,0x2b000000,0x34000000,0x0,0x0,0x0,0x39000000,0x23000000,0x10000000,0x3000000,0x3000000,0x10000000,0x23000000,
0x39000000,0x0,0x3000000,0x38000000,0x11000000,0x3000000,0x0,0x0,0x3000000,0x11000000,0x38000000,0x3000000,0x34000000,0x2a000000,
@@ -120,7 +120,7 @@ static const QRgb client_edges_dark_data[] = {
0x0,0x41000000,0x44000000,0x44000000,0x41000000,0x0,0x0,0x0
};
-static const QRgb client_edges_data[] = {
+static const TQRgb client_edges_data[] = {
0x0,0x0,0x0,0x2fffffff,0x31ffffff,0x31ffffff,0x2fffffff,0x0,0x0,0x0,0x0,0x0,0x2effffff,0x25ffffff,
0x11ffffff,0x11ffffff,0x25ffffff,0x2effffff,0x0,0x0,0x0,0x34ffffff,0x1fffffff,0xeffffff,0x3ffffff,0x3ffffff,0xeffffff,0x1fffffff,
0x34ffffff,0x0,0x2ffffff,0x33ffffff,0xeffffff,0x3ffffff,0x0,0x0,0x3ffffff,0xeffffff,0x33ffffff,0x2ffffff,0x2fffffff,0x1fffffff,
@@ -132,17 +132,17 @@ static const QRgb client_edges_data[] = {
0x0,0x12000000,0x13000000,0x13000000,0x12000000,0x0,0x0,0x0
};
-static const QRgb client_help_5x8_data[] = {
+static const TQRgb client_help_5x8_data[] = {
0x22a2a2a,0x772a2a2a,0xc22a2a2a,0xbd2a2a2a,0x302a2a2a,0x3b2a2a2a,0xd22a2a2a,0x612a2a2a,0x862a2a2a,0xbd2a2a2a,0x22a2a2a,0x22a2a2a,0x0,0x5b2a2a2a,
0xba2a2a2a,0x0,0x0,0x462a2a2a,0xbd2a2a2a,0x3e2a2a2a,0x0,0x0,0xd12a2a2a,0x682a2a2a,0x0,0x0,0x0,0x542a2a2a,
0x2a2a2a2a,0x0,0x0,0x0,0xb82a2a2a,0x5b2a2a2a,0x0,0x0,0x0,0x262a2a2a,0x82a2a2a,0x0
};
-static const QRgb client_line_6x2_data[] = {
+static const TQRgb client_line_6x2_data[] = {
0x852a2a2a,0xbe2a2a2a,0xbe2a2a2a,0xbe2a2a2a,0xbe2a2a2a,0x852a2a2a,0x432a2a2a,0x5f2a2a2a,0x5f2a2a2a,0x5f2a2a2a,0x5f2a2a2a,0x432a2a2a
};
-static const QRgb client_max_8x8_data[] = {
+static const TQRgb client_max_8x8_data[] = {
0x0,0x0,0x0,0x852a2a2a,0x442a2a2a,0x0,0x0,0x0,0x0,0x0,0x0,0xbe2a2a2a,0x602a2a2a,0x0,
0x0,0x0,0x12a2a2a,0x12a2a2a,0x0,0xbe2a2a2a,0x602a2a2a,0x0,0x0,0x0,0x852a2a2a,0xbe2a2a2a,0xbe2a2a2a,0xbe2a2a2a,
0xbe2a2a2a,0xbe2a2a2a,0xbe2a2a2a,0x852a2a2a,0x442a2a2a,0x602a2a2a,0x602a2a2a,0xbe2a2a2a,0x902a2a2a,0x622a2a2a,0x632a2a2a,0x452a2a2a,0x0,0x0,
@@ -150,27 +150,27 @@ static const QRgb client_max_8x8_data[] = {
0x0,0x0,0x0,0x852a2a2a,0x442a2a2a,0x0,0x0,0x0
};
-static const QRgb client_right_lines2_data[] = {
+static const TQRgb client_right_lines2_data[] = {
0xfffffff,0x24ffffff,0xfffffff,0x24ffffff,0xfffffff,0x24ffffff,0xfffffff,0x24ffffff,0xfffffff,0x24ffffff,0xfffffff,0x24ffffff,0xfffffff,0x24ffffff,
0xfffffff,0x24ffffff,0xfffffff,0x24ffffff,0xfffffff,0x24ffffff
};
-static const QRgb client_right_lines_dark_data[] = {
+static const TQRgb client_right_lines_dark_data[] = {
0x19000000,0x36000000,0x19000000,0x36000000,0x19000000,0x36000000,0x19000000,0x36000000,0x19000000,0x36000000,0x19000000,0x36000000,0x19000000,0x36000000,
0x19000000,0x36000000,0x19000000,0x36000000,0x19000000,0x36000000
};
-static const QRgb client_topLines2_data[] = {
+static const TQRgb client_topLines2_data[] = {
0x39ffffff,0x39ffffff,0x39ffffff,0x39ffffff,0x39ffffff,0x39ffffff,0x39ffffff,0x39ffffff,0x39ffffff,0x39ffffff,0x11ffffff,0x11ffffff,0x11ffffff,0x11ffffff,
0x11ffffff,0x11ffffff,0x11ffffff,0x11ffffff,0x11ffffff,0x11ffffff
};
-static const QRgb client_top_lines_dark_data[] = {
+static const TQRgb client_top_lines_dark_data[] = {
0x36000000,0x36000000,0x36000000,0x36000000,0x36000000,0x36000000,0x36000000,0x36000000,0x36000000,0x36000000,0x13000000,0x13000000,0x13000000,0x13000000,
0x13000000,0x13000000,0x13000000,0x13000000,0x13000000,0x13000000
};
-static const QRgb client_upArrow_6x8_data[] = {
+static const TQRgb client_upArrow_6x8_data[] = {
0x0,0x0,0x492a2a2a,0x142a2a2a,0x0,0x0,0x0,0x4a2a2a2a,0xb92a2a2a,0xa82a2a2a,0x1e2a2a2a,0x0,0x572a2a2a,0xb92a2a2a,
0xb92a2a2a,0xb82a2a2a,0xac2a2a2a,0x1d2a2a2a,0x0,0x0,0xb92a2a2a,0x5c2a2a2a,0x0,0x0,0x0,0x0,0xb92a2a2a,0x5c2a2a2a,
0x0,0x0,0x0,0x0,0xb92a2a2a,0x5c2a2a2a,0x0,0x0,0x0,0x0,0xb92a2a2a,0x5c2a2a2a,0x0,0x0,
@@ -182,7 +182,7 @@ static struct EmbedImage {
int width, height, depth;
const unsigned char *data;
int numColors;
- const QRgb *colorTable;
+ const TQRgb *colorTable;
bool alpha;
const char *name;
} embed_image_vec[] = {
@@ -206,20 +206,20 @@ static struct EmbedImage {
{ 0, 0, 0, 0, 0, 0, 0, 0 }
};
-static const QImage& qembed_findImage( const QString& name )
+static const TQImage& qembed_findImage( const TQString& name )
{
- static QDict<QImage> dict;
- QImage* img = dict.find( name );
+ static TQDict<TQImage> dict;
+ TQImage* img = dict.find( name );
if ( !img ) {
for ( int i = 0; embed_image_vec[i].data; i++ ) {
if ( strcmp(embed_image_vec[i].name, name.latin1()) == 0 ) {
- img = new QImage((uchar*)embed_image_vec[i].data,
+ img = new TQImage((uchar*)embed_image_vec[i].data,
embed_image_vec[i].width,
embed_image_vec[i].height,
embed_image_vec[i].depth,
- (QRgb*)embed_image_vec[i].colorTable,
+ (TQRgb*)embed_image_vec[i].colorTable,
embed_image_vec[i].numColors,
- QImage::BigEndian );
+ TQImage::BigEndian );
if ( embed_image_vec[i].alpha )
img->setAlphaBuffer( TRUE );
dict.insert( name, img );
@@ -227,7 +227,7 @@ static const QImage& qembed_findImage( const QString& name )
}
}
if ( !img ) {
- static QImage dummy;
+ static TQImage dummy;
return dummy;
}
}
diff --git a/client/config/config.h b/client/config/config.h
index 3ccdc1a..fbe5494 100644
--- a/client/config/config.h
+++ b/client/config/config.h
@@ -23,17 +23,17 @@
#ifndef DOMINOCONFIG_H
#define DOMINOCONFIG_H
-#include <qcheckbox.h>
+#include <tqcheckbox.h>
#include <kconfig.h>
-#include <qvbox.h>
+#include <tqvbox.h>
#include <kcolorbutton.h>
-class DominoConfig: public QObject
+class DominoConfig: public TQObject
{
Q_OBJECT
public:
- DominoConfig( KConfig* config, QWidget* parent );
+ DominoConfig( KConfig* config, TQWidget* parent );
~DominoConfig();
// These public signals/slots work similar to KCM modules
@@ -50,22 +50,22 @@ class DominoConfig: public QObject
void loadButtonContourColors();
private:
KConfig* conf;
- QVBox* vBox;
- QCheckBox* customBorderColor;
+ TQVBox* vBox;
+ TQCheckBox* customBorderColor;
KColorButton* borderColor;
- QCheckBox* customButtonColor;
+ TQCheckBox* customButtonColor;
KColorButton* buttonColor;
- QCheckBox* customButtonIconColor;
+ TQCheckBox* customButtonIconColor;
KColorButton* buttonIconColor;
- QCheckBox* showInactiveButtons;
- QCheckBox* showButtonIcons;
- QCheckBox* customGradientColors;
+ TQCheckBox* showInactiveButtons;
+ TQCheckBox* showButtonIcons;
+ TQCheckBox* customGradientColors;
KColorButton* topGradientColor;
KColorButton* bottomGradientColor;
- QCheckBox* darkFrame;
+ TQCheckBox* darkFrame;
- QCheckBox* useDominoStyleContourColors;
+ TQCheckBox* useDominoStyleContourColors;
KColorButton* buttonContourColor;
KColorButton* buttonMouseOverContourColor;
KColorButton* buttonPressedContourColor;
diff --git a/client/dominoclient.cpp b/client/dominoclient.cpp
index 4fee0cd..c8b0c49 100644
--- a/client/dominoclient.cpp
+++ b/client/dominoclient.cpp
@@ -25,16 +25,16 @@
#include <kconfig.h>
#include <kglobal.h>
-#include <qlayout.h>
-#include <qbitmap.h>
-#include <qimage.h>
-#include <qapplication.h>
-#include <qlabel.h>
-#include <qpixmap.h>
+#include <tqlayout.h>
+#include <tqbitmap.h>
+#include <tqimage.h>
+#include <tqapplication.h>
+#include <tqlabel.h>
+#include <tqpixmap.h>
#include <X11/extensions/shape.h>
-#include <qwmatrix.h>
-#include <qpainter.h>
-#include <qsettings.h>
+#include <tqwmatrix.h>
+#include <tqpainter.h>
+#include <tqsettings.h>
namespace Domino
@@ -46,53 +46,53 @@ const int titleEdgeTop = 3;
const int titleEdgeBottom = 1;
static int titleHeight;
-static QPixmap* buttonPix;
-static QPixmap* buttonHidePix;
-static QPixmap* titleBarPix;
-static QPixmap* borderTopLeftPix;
-static QPixmap* borderTopRightPix;
-static QPixmap* borderBottomPix;
-static QPixmap* borderBottomLeftPix;
-static QPixmap* borderBottomRightPix;
-static QPixmap* borderLeftPix;
-static QPixmap* borderRightPix;
-
-
-static QPixmap* closeButtonIcon;
-static QPixmap* minButtonIcon;
-static QPixmap* maxButtonIcon;
-static QPixmap* helpButtonIcon;
-static QPixmap* onAllDesktopsButtonIcon;
-static QPixmap* shadeButtonIcon;
-static QPixmap* aboveButtonIcon;
-static QPixmap* belowButtonIcon;
-
-static QPixmap* pressedCloseButtonIcon;
-static QPixmap* pressedMinButtonIcon;
-static QPixmap* pressedMaxButtonIcon;
-static QPixmap* pressedHelpButtonIcon;
-static QPixmap* pressedOnAllDesktopsButtonIcon;
-static QPixmap* pressedShadeButtonIcon;
-static QPixmap* pressedAboveButtonIcon;
-static QPixmap* pressedBelowButtonIcon;
-
-static QPixmap* mouseOverCloseButtonIcon;
-static QPixmap* mouseOverMinButtonIcon;
-static QPixmap* mouseOverMaxButtonIcon;
-static QPixmap* mouseOverHelpButtonIcon;
-static QPixmap* mouseOverOnAllDesktopsButtonIcon;
-static QPixmap* mouseOverShadeButtonIcon;
-static QPixmap* mouseOverAboveButtonIcon;
-static QPixmap* mouseOverBelowButtonIcon;
+static TQPixmap* buttonPix;
+static TQPixmap* buttonHidePix;
+static TQPixmap* titleBarPix;
+static TQPixmap* borderTopLeftPix;
+static TQPixmap* borderTopRightPix;
+static TQPixmap* borderBottomPix;
+static TQPixmap* borderBottomLeftPix;
+static TQPixmap* borderBottomRightPix;
+static TQPixmap* borderLeftPix;
+static TQPixmap* borderRightPix;
+
+
+static TQPixmap* closeButtonIcon;
+static TQPixmap* minButtonIcon;
+static TQPixmap* maxButtonIcon;
+static TQPixmap* helpButtonIcon;
+static TQPixmap* onAllDesktopsButtonIcon;
+static TQPixmap* shadeButtonIcon;
+static TQPixmap* aboveButtonIcon;
+static TQPixmap* belowButtonIcon;
+
+static TQPixmap* pressedCloseButtonIcon;
+static TQPixmap* pressedMinButtonIcon;
+static TQPixmap* pressedMaxButtonIcon;
+static TQPixmap* pressedHelpButtonIcon;
+static TQPixmap* pressedOnAllDesktopsButtonIcon;
+static TQPixmap* pressedShadeButtonIcon;
+static TQPixmap* pressedAboveButtonIcon;
+static TQPixmap* pressedBelowButtonIcon;
+
+static TQPixmap* mouseOverCloseButtonIcon;
+static TQPixmap* mouseOverMinButtonIcon;
+static TQPixmap* mouseOverMaxButtonIcon;
+static TQPixmap* mouseOverHelpButtonIcon;
+static TQPixmap* mouseOverOnAllDesktopsButtonIcon;
+static TQPixmap* mouseOverShadeButtonIcon;
+static TQPixmap* mouseOverAboveButtonIcon;
+static TQPixmap* mouseOverBelowButtonIcon;
static bool buttonInputShape;
-static QBitmap* buttonShapeBitmap;
+static TQBitmap* buttonShapeBitmap;
-static QColor background;
-static QColor topGradientColor;
-static QColor bottomGradientColor;
-static QColor topBorderGradientColor;
-static QColor bottomBorderGradientColor;
+static TQColor background;
+static TQColor topGradientColor;
+static TQColor bottomGradientColor;
+static TQColor topBorderGradientColor;
+static TQColor bottomBorderGradientColor;
static bool showButtonIcons;
static bool showInactiveButtons;
@@ -106,8 +106,8 @@ DominoHandler::DominoHandler()
{
int ignore, maj, min;
- if(XShapeQueryExtension(qt_xdisplay(), &ignore, &ignore) &&
- XShapeQueryVersion(qt_xdisplay(), &maj, &min) &&
+ if(XShapeQueryExtension(tqt_xdisplay(), &ignore, &ignore) &&
+ XShapeQueryVersion(tqt_xdisplay(), &maj, &min) &&
maj >= 1 && min >= 1) {
buttonInputShape = true;
@@ -159,8 +159,8 @@ unsigned long DominoHandler::readConfig( bool update )
KConfig conf("kwindominorc");
conf.setGroup("General");
- titleHeight = QMAX(QFontMetrics(options()->font(true)).height(), 16);
- background = qApp->palette().active().background();
+ titleHeight = TQMAX(TQFontMetrics(options()->font(true)).height(), 16);
+ background = tqApp->palette().active().background();
customBorderColor = conf.readBoolEntry("customBorderColor", true);
borderColor = customBorderColor ? conf.readEntry("borderColor", "#777B7F") : background;
@@ -174,10 +174,10 @@ unsigned long DominoHandler::readConfig( bool update )
darkLines = conf.readBoolEntry("darkFrame", false);
if(!conf.readBoolEntry( "customGradientColors", false)) {
- topGradientColor = alphaBlendColors(background, Qt::white, 180);
- bottomGradientColor = alphaBlendColors(background, Qt::black, 230);
- topBorderGradientColor = alphaBlendColors(borderColor, Qt::white, 180);
- bottomBorderGradientColor = alphaBlendColors(borderColor, Qt::black, 230);
+ topGradientColor = alphaBlendColors(background, TQt::white, 180);
+ bottomGradientColor = alphaBlendColors(background, TQt::black, 230);
+ topBorderGradientColor = alphaBlendColors(borderColor, TQt::white, 180);
+ bottomBorderGradientColor = alphaBlendColors(borderColor, TQt::black, 230);
}
else {
topGradientColor = conf.readEntry("topGradientColor", "#ffffff");
@@ -191,7 +191,7 @@ unsigned long DominoHandler::readConfig( bool update )
}
if(conf.readBoolEntry("useDominoStyleContourColors", true)) {
- QSettings s;
+ TQSettings s;
buttonContourColor = s.readEntry("/domino/Settings/buttonContourColor", background.dark(250).name());
buttonMouseOverContourColor = s.readEntry("/domino/Settings/buttonMouseOverContourColor", background.dark(250).name());
buttonPressedContourColor = s.readEntry("/domino/Settings/buttonPressedContourColor", background.dark(250).name());
@@ -210,10 +210,10 @@ unsigned long DominoHandler::readConfig( bool update )
void DominoHandler::createPixmaps()
{
- QImage edges;
- QImage topLines;
- QImage rightLines;
- QImage bottomLines;
+ TQImage edges;
+ TQImage topLines;
+ TQImage rightLines;
+ TQImage bottomLines;
if(darkLines) {
edges = qembed_findImage("client_edges_dark");
@@ -232,14 +232,14 @@ void DominoHandler::createPixmaps()
int titleBarHeight = titleHeight+titleEdgeTop+titleEdgeBottom;
- QWMatrix m;
+ TQWMatrix m;
m.rotate(180);
- titleBarPix = new QPixmap(QSize(10, titleBarHeight));
+ titleBarPix = new TQPixmap(TQSize(10, titleBarHeight));
titleBarPix->fill(background);
- QRect r(titleBarPix->rect());
- QPainter p(titleBarPix);
- QRect rect(r.x(), r.y(), r.width(), titleGradientHeight);
+ TQRect r(titleBarPix->rect());
+ TQPainter p(titleBarPix);
+ TQRect rect(r.x(), r.y(), r.width(), titleGradientHeight);
renderGradient(&p, rect, topGradientColor, background, "titleBar");
p.drawPixmap(0, 0, topLines);
p.end();
@@ -248,23 +248,23 @@ void DominoHandler::createPixmaps()
///////// borders
// sides
- QPixmap sideLinesRight = rightLines;
+ TQPixmap sideLinesRight = rightLines;
- borderRightPix = new QPixmap(5, 10);
+ borderRightPix = new TQPixmap(5, 10);
borderRightPix->fill(borderColor);
p.begin(borderRightPix);
p.drawPixmap(3, 0, sideLinesRight);
p.end();
- borderLeftPix = new QPixmap(borderRightPix->xForm(m));
+ borderLeftPix = new TQPixmap(borderRightPix->xForm(m));
// edges
- borderTopLeftPix = new QPixmap(QSize(5, titleBarHeight));
+ borderTopLeftPix = new TQPixmap(TQSize(5, titleBarHeight));
borderTopLeftPix->fill(borderColor);
p.begin(borderTopLeftPix);
- r = QRect(0, 0, 5, titleGradientHeight);
+ r = TQRect(0, 0, 5, titleGradientHeight);
// if the gradient color is equal to the background color, we make the border also flat.
renderGradient(&p, r, topGradientColor == background ? borderColor : topBorderGradientColor, borderColor, "borderTopLeftPix");
- borderTopRightPix = new QPixmap(*borderTopLeftPix);
+ borderTopRightPix = new TQPixmap(*borderTopLeftPix);
p.drawPixmap(0, 1, edges, 0, 0, 5, 6);
p.drawTiledPixmap(0, 7, 2, titleBarHeight, sideLinesRight.xForm(m));
p.end();
@@ -274,12 +274,12 @@ void DominoHandler::createPixmaps()
p.end();
- borderBottomRightPix = new QPixmap(QSize(5, bottomBorderHeight));
+ borderBottomRightPix = new TQPixmap(TQSize(5, bottomBorderHeight));
borderBottomRightPix->fill(borderColor);
p.begin(borderBottomRightPix);
- r = QRect(0, bottomBorderHeight-6, 5, 6);
+ r = TQRect(0, bottomBorderHeight-6, 5, 6);
renderGradient(&p, r, borderColor, bottomGradientColor == background ? borderColor : bottomBorderGradientColor, "borderBottomRightPix");
- borderBottomLeftPix = new QPixmap(*borderBottomRightPix);
+ borderBottomLeftPix = new TQPixmap(*borderBottomRightPix);
p.drawPixmap(0, bottomBorderHeight-7, edges, 5, 6, 5, 6);
p.drawPixmap(3, 0, sideLinesRight, 0, 0, 2, borderBottomLeftPix->height()-7);
p.end();
@@ -290,10 +290,10 @@ void DominoHandler::createPixmaps()
p.drawPixmap(0, 0, sideLinesRight.xForm(m), 0, 0, 2, borderBottomLeftPix->height()-7);
p.end();
- borderBottomPix = new QPixmap(QSize(10, bottomBorderHeight));
+ borderBottomPix = new TQPixmap(TQSize(10, bottomBorderHeight));
borderBottomPix->fill(background);
p.begin(borderBottomPix);
- r = QRect(0, bottomBorderHeight-6, 10, 6);
+ r = TQRect(0, bottomBorderHeight-6, 10, 6);
renderGradient(&p, r, background, bottomGradientColor, "borderBottom");
p.drawPixmap(0, bottomBorderHeight-2, bottomLines);
p.end();
@@ -304,42 +304,42 @@ void DominoHandler::createPixmaps()
////////////////////////////////////////////////////////////////////////
if(buttonInputShape) {
- QRegion buttonClip(6,2,6,1);
- buttonClip += QRegion(5,3,8,1);
- buttonClip += QRegion(4,4,10,1);
- buttonClip += QRegion(3,5,12,1);
- buttonClip += QRegion(2,6,14,6);
- buttonClip += QRegion(3,12,12,1);
- buttonClip += QRegion(4,13,10,1);
- buttonClip += QRegion(5,14,8,1);
- buttonClip += QRegion(6,15,6,1);
+ TQRegion buttonClip(6,2,6,1);
+ buttonClip += TQRegion(5,3,8,1);
+ buttonClip += TQRegion(4,4,10,1);
+ buttonClip += TQRegion(3,5,12,1);
+ buttonClip += TQRegion(2,6,14,6);
+ buttonClip += TQRegion(3,12,12,1);
+ buttonClip += TQRegion(4,13,10,1);
+ buttonClip += TQRegion(5,14,8,1);
+ buttonClip += TQRegion(6,15,6,1);
- buttonShapeBitmap = new QBitmap(16, titleBarHeight, true);
- QPainter p(buttonShapeBitmap);
+ buttonShapeBitmap = new TQBitmap(16, titleBarHeight, true);
+ TQPainter p(buttonShapeBitmap);
p.setClipRegion(buttonClip);
- p.fillRect(QRect(0, 0, 16, titleBarHeight), Qt::color1);
+ p.fillRect(TQRect(0, 0, 16, titleBarHeight), TQt::color1);
}
- QPixmap* buttonShadow = new QPixmap(qembed_findImage("clientButtonShadow"));
- QPixmap* buttonPressed = new QPixmap(qembed_findImage("clientButtonPressed"));
+ TQPixmap* buttonShadow = new TQPixmap(qembed_findImage("clientButtonShadow"));
+ TQPixmap* buttonPressed = new TQPixmap(qembed_findImage("clientButtonPressed"));
- buttonPix = new QPixmap(QSize(16, titleBarHeight));
+ buttonPix = new TQPixmap(TQSize(16, titleBarHeight));
p.begin(buttonPix);
p.drawTiledPixmap(0, 0, titleBarHeight, titleBarHeight, *titleBarPix, 0, titleEdgeTop);
//////////// custom color
- r = QRect(buttonPix->rect());
- QRegion buttonClip(5,2,6,1);
- buttonClip += QRegion(4,3,8,1);
- buttonClip += QRegion(3,4,10,1);
- buttonClip += QRegion(2,5,12,6);
- buttonClip += QRegion(3,11,10,1);
- buttonClip += QRegion(4,12,8,1);
- buttonClip += QRegion(5,13,6,1);
+ r = TQRect(buttonPix->rect());
+ TQRegion buttonClip(5,2,6,1);
+ buttonClip += TQRegion(4,3,8,1);
+ buttonClip += TQRegion(3,4,10,1);
+ buttonClip += TQRegion(2,5,12,6);
+ buttonClip += TQRegion(3,11,10,1);
+ buttonClip += TQRegion(4,12,8,1);
+ buttonClip += TQRegion(5,13,6,1);
p.setClipRegion(buttonClip);
- p.fillRect(QRect(0, 0, r.width(), r.height()), buttonColor);
- QRect gr(0, -3, r.width(), titleGradientHeight);
+ p.fillRect(TQRect(0, 0, r.width(), r.height()), buttonColor);
+ TQRect gr(0, -3, r.width(), titleGradientHeight);
renderGradient(&p, gr, topGradientColor, buttonColor, "titleBar");
p.setClipping(false);
///////////
@@ -347,14 +347,14 @@ void DominoHandler::createPixmaps()
p.end();
- QPixmap* pressedButtonPix = new QPixmap(*buttonPix);
+ TQPixmap* pressedButtonPix = new TQPixmap(*buttonPix);
p.begin(pressedButtonPix);
p.drawPixmap(0, 0, tintImage(qembed_findImage("clientButtonContour"), buttonPressedContourColor));
p.drawPixmap(0, 0, *buttonPressed);
p.end();
- QPixmap* mouseOverButtonPix = new QPixmap(*buttonPix);
+ TQPixmap* mouseOverButtonPix = new TQPixmap(*buttonPix);
p.begin(mouseOverButtonPix);
p.drawPixmap(0, 0, tintImage(qembed_findImage("clientButtonContour"), buttonMouseOverContourColor));
p.end();
@@ -365,7 +365,7 @@ void DominoHandler::createPixmaps()
p.end();
- buttonHidePix = new QPixmap(QSize(buttonPix->width(), titleBarHeight));
+ buttonHidePix = new TQPixmap(TQSize(buttonPix->width(), titleBarHeight));
p.begin(buttonHidePix);
p.drawTiledPixmap(0, 0, buttonHidePix->width(), buttonHidePix->height(), *titleBarPix, 0, titleEdgeTop);
p.end();
@@ -376,75 +376,75 @@ void DominoHandler::createPixmaps()
///////// icons
///////////////////////////////////////////////////////////////////////
- QPixmap* icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("closeButtonIcon"), buttonIconColor) : qembed_findImage("closeButtonIcon"));
- closeButtonIcon = new QPixmap(*buttonPix);
+ TQPixmap* icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("closeButtonIcon"), buttonIconColor) : qembed_findImage("closeButtonIcon"));
+ closeButtonIcon = new TQPixmap(*buttonPix);
bitBlt(closeButtonIcon, 5, 5, icon);
- pressedCloseButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedCloseButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedCloseButtonIcon, 5, 5, icon);
- mouseOverCloseButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverCloseButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverCloseButtonIcon, 5, 5, icon);
delete icon;
- icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("maxButtonIcon"), buttonIconColor) : qembed_findImage("maxButtonIcon"));
- maxButtonIcon = new QPixmap(*buttonPix);
+ icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("maxButtonIcon"), buttonIconColor) : qembed_findImage("maxButtonIcon"));
+ maxButtonIcon = new TQPixmap(*buttonPix);
bitBlt(maxButtonIcon, 4, 4, icon);
- pressedMaxButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedMaxButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedMaxButtonIcon, 4, 4, icon);
- mouseOverMaxButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverMaxButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverMaxButtonIcon, 4, 4, icon);
delete icon;
- icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("minButtonIcon"), buttonIconColor) : qembed_findImage("minButtonIcon"));
- minButtonIcon = new QPixmap(*buttonPix);
+ icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("minButtonIcon"), buttonIconColor) : qembed_findImage("minButtonIcon"));
+ minButtonIcon = new TQPixmap(*buttonPix);
bitBlt(minButtonIcon, 5, 9, icon);
- pressedMinButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedMinButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedMinButtonIcon, 5, 9, icon);
- mouseOverMinButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverMinButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverMinButtonIcon, 5, 9, icon);
delete icon;
- icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("helpButtonIcon"), buttonIconColor) : qembed_findImage("helpButtonIcon"));
- helpButtonIcon = new QPixmap(*buttonPix);
+ icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("helpButtonIcon"), buttonIconColor) : qembed_findImage("helpButtonIcon"));
+ helpButtonIcon = new TQPixmap(*buttonPix);
bitBlt(helpButtonIcon, 5, 4, icon);
- pressedHelpButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedHelpButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedHelpButtonIcon, 5, 4, icon);
- mouseOverHelpButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverHelpButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverHelpButtonIcon, 5, 4, icon);
delete icon;
- icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("onAllDesktopsButtonIcon"), buttonIconColor) : qembed_findImage("onAllDesktopsButtonIcon"));
- onAllDesktopsButtonIcon = new QPixmap(*buttonPix);
+ icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("onAllDesktopsButtonIcon"), buttonIconColor) : qembed_findImage("onAllDesktopsButtonIcon"));
+ onAllDesktopsButtonIcon = new TQPixmap(*buttonPix);
bitBlt(onAllDesktopsButtonIcon, 6, 6, icon);
- pressedOnAllDesktopsButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedOnAllDesktopsButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedOnAllDesktopsButtonIcon, 6, 6, icon);
- mouseOverOnAllDesktopsButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverOnAllDesktopsButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverOnAllDesktopsButtonIcon, 6, 6, icon);
delete icon;
- icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("aboveButtonIcon"), buttonIconColor) : qembed_findImage("aboveButtonIcon"));
- aboveButtonIcon = new QPixmap(*buttonPix);
+ icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("aboveButtonIcon"), buttonIconColor) : qembed_findImage("aboveButtonIcon"));
+ aboveButtonIcon = new TQPixmap(*buttonPix);
bitBlt(aboveButtonIcon, 5, 4, icon);
- pressedAboveButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedAboveButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedAboveButtonIcon, 5, 4, icon);
- mouseOverAboveButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverAboveButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverAboveButtonIcon, 5, 4, icon);
delete icon;
- icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("aboveButtonIcon").xForm(m), buttonIconColor) : qembed_findImage("aboveButtonIcon").xForm(m));
- belowButtonIcon = new QPixmap(*buttonPix);
+ icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("aboveButtonIcon").xForm(m), buttonIconColor) : qembed_findImage("aboveButtonIcon").xForm(m));
+ belowButtonIcon = new TQPixmap(*buttonPix);
bitBlt(belowButtonIcon, 5, 4, icon);
- pressedBelowButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedBelowButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedBelowButtonIcon, 5, 4, icon);
- mouseOverBelowButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverBelowButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverBelowButtonIcon, 5, 4, icon);
delete icon;
- icon = new QPixmap(customButtonIconColor ? tintImage(qembed_findImage("minButtonIcon"), buttonIconColor) : qembed_findImage("minButtonIcon"));
- shadeButtonIcon = new QPixmap(*buttonPix);
+ icon = new TQPixmap(customButtonIconColor ? tintImage(qembed_findImage("minButtonIcon"), buttonIconColor) : qembed_findImage("minButtonIcon"));
+ shadeButtonIcon = new TQPixmap(*buttonPix);
bitBlt(shadeButtonIcon, 5, 5, icon);
- pressedShadeButtonIcon = new QPixmap(*pressedButtonPix);
+ pressedShadeButtonIcon = new TQPixmap(*pressedButtonPix);
bitBlt(pressedShadeButtonIcon, 5, 5, icon);
- mouseOverShadeButtonIcon = new QPixmap(*mouseOverButtonPix);
+ mouseOverShadeButtonIcon = new TQPixmap(*mouseOverButtonPix);
bitBlt(mouseOverShadeButtonIcon, 5, 5, icon);
delete icon;
@@ -531,7 +531,7 @@ DominoButton::DominoButton(ButtonType type, DominoClient *parent, const char *na
client = parent;
#ifdef ShapeInput
if(buttonInputShape && buttonShapeBitmap ) {
- XShapeCombineMask (qt_xdisplay(),
+ XShapeCombineMask (tqt_xdisplay(),
winId(),
ShapeInput,
0,
@@ -551,7 +551,7 @@ DominoButton::~DominoButton()
void DominoButton::reset(unsigned long changed)
{
if (changed&SizeChange || changed&ManualReset) {
- setBackgroundOrigin(QWidget::WidgetOrigin);
+ setBackgroundOrigin(TQWidget::WidgetOrigin);
setErasePixmap(showInactiveButtons ? *buttonPix : *buttonHidePix);
}
@@ -564,7 +564,7 @@ void DominoButton::reset(unsigned long changed)
}
-void DominoButton::drawButton(QPainter *p)
+void DominoButton::drawButton(TQPainter *p)
{
if (!Domino_initialized)
return;
@@ -610,7 +610,7 @@ void DominoButton::drawButton(QPainter *p)
-void DominoButton::enterEvent(QEvent */*e*/)
+void DominoButton::enterEvent(TQEvent */*e*/)
{
if(!client->isActive() && !showInactiveButtons)
@@ -621,7 +621,7 @@ void DominoButton::enterEvent(QEvent */*e*/)
}
-void DominoButton::leaveEvent(QEvent */*e*/)
+void DominoButton::leaveEvent(TQEvent */*e*/)
{
isMouseOver=false;
repaint(false);
@@ -649,17 +649,17 @@ DominoClient::~DominoClient()
delete borderBottom;
}
-QString DominoClient::visibleName() const
+TQString DominoClient::visibleName() const
{
return "Domino";
}
-QString DominoClient::defaultButtonsLeft() const
+TQString DominoClient::defaultButtonsLeft() const
{
return "MF";
}
-QString DominoClient::defaultButtonsRight() const
+TQString DominoClient::defaultButtonsRight() const
{
return "HIAX";
}
@@ -776,7 +776,7 @@ void DominoClient::init()
menuButton = 0;
globalMouseTracking = false;
titleBarMouseOver = false;
- QWidget* w = new QWidget(KDecoration::initialParentWidget(), "clientMainWidget", WNoAutoErase|WStaticContents);
+ TQWidget* w = new TQWidget(KDecoration::initialParentWidget(), "clientMainWidget", WNoAutoErase|WStaticContents);
setMainWidget(w);
widget()->setBackgroundMode(NoBackground);
@@ -794,48 +794,48 @@ void DominoClient::createLayout()
int titleBarHeight = titleHeight+titleEdgeTop+titleEdgeBottom;
- mainlayout = new QGridLayout(widget(), 3, 3, 0);
+ mainlayout = new TQGridLayout(widget(), 3, 3, 0);
titleBar = new TitleBar(widget(), "titlebar");
titleBar->client = this;
titleBar->setMouseTracking(true);
- borderTopLeft = new QWidget(widget(), "borderTopLeft", Qt::WNoAutoErase);
+ borderTopLeft = new TQWidget(widget(), "borderTopLeft", TQt::WNoAutoErase);
borderTopLeft->setMouseTracking(true);
- borderTopRight = new QWidget(widget(), "borderTopRight", Qt::WNoAutoErase);
+ borderTopRight = new TQWidget(widget(), "borderTopRight", TQt::WNoAutoErase);
borderTopRight->setMouseTracking(true);
- borderBottomLeft = new QWidget(widget(), "borderBottomLeft", Qt::WNoAutoErase);
+ borderBottomLeft = new TQWidget(widget(), "borderBottomLeft", TQt::WNoAutoErase);
borderBottomLeft->setMouseTracking(true);
- borderBottomRight = new QWidget(widget(), "borderBottomRight", Qt::WNoAutoErase);
+ borderBottomRight = new TQWidget(widget(), "borderBottomRight", TQt::WNoAutoErase);
borderBottomRight->setMouseTracking(true);
- borderLeft = new QWidget(widget(), "borderLeft", Qt::WNoAutoErase);
+ borderLeft = new TQWidget(widget(), "borderLeft", TQt::WNoAutoErase);
borderLeft->setMouseTracking(true);
- borderRight = new QWidget(widget(), "borderRight", Qt::WNoAutoErase);
+ borderRight = new TQWidget(widget(), "borderRight", TQt::WNoAutoErase);
borderRight->setMouseTracking(true);
- borderBottom = new QWidget(widget(), "borderBottom", Qt::WNoAutoErase);
+ borderBottom = new TQWidget(widget(), "borderBottom", TQt::WNoAutoErase);
borderBottom->setMouseTracking(true);
titleBar->setFixedHeight(titleBarHeight);
- titleBar->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+ titleBar->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed);
borderTopLeft->setFixedSize(borderWidth, titleBarHeight);
borderTopRight->setFixedSize(borderWidth, titleBarHeight);
borderLeft->setFixedWidth(borderWidth);
- borderLeft->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+ borderLeft->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Expanding);
borderRight->setFixedWidth(borderWidth);
- borderRight->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
+ borderRight->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Expanding);
borderBottomLeft->setFixedSize(borderWidth, bottomBorderHeight);
borderBottomRight->setFixedSize(borderWidth, bottomBorderHeight);
borderBottom->setFixedHeight(bottomBorderHeight);
- borderBottom->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+ borderBottom->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed);
mainlayout->addWidget(titleBar, 0,1);
mainlayout->addWidget(borderTopLeft, 0,0);
mainlayout->addWidget(borderTopRight, 0,2);
mainlayout->addWidget(borderLeft, 1,0);
- mainlayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Expanding));
+ mainlayout->addItem(new TQSpacerItem(1, 1, TQSizePolicy::Expanding, TQSizePolicy::Expanding));
mainlayout->addWidget(borderRight, 1,2);
mainlayout->addWidget(borderBottomLeft, 2,0);
@@ -883,38 +883,38 @@ void DominoClient::updateMask()
clearMask();
return;
}
- QRect r(widget()->rect());
+ TQRect r(widget()->rect());
- QRegion mask(r.x()+5, r.y(), r.width()-10, r.height());
- mask += QRect(r.x()+3, r.y()+1, r.width()-6, r.height()-2);
- mask += QRect(r.x()+2, r.y()+2, r.width()-4, r.height()-4);
- mask += QRect(r.x()+1, r.y()+3, r.width()-2, r.height()-6);
- mask += QRect(r.x(), r.y()+5, r.width(), r.height()-10);
+ TQRegion mask(r.x()+5, r.y(), r.width()-10, r.height());
+ mask += TQRect(r.x()+3, r.y()+1, r.width()-6, r.height()-2);
+ mask += TQRect(r.x()+2, r.y()+2, r.width()-4, r.height()-4);
+ mask += TQRect(r.x()+1, r.y()+3, r.width()-2, r.height()-6);
+ mask += TQRect(r.x(), r.y()+5, r.width(), r.height()-10);
setMask(mask);
}
void DominoClient::updateCaption()
{
- QRect r(titleBar->rect());
+ TQRect r(titleBar->rect());
- QPixmap* titleBar_pix = new QPixmap(r.size());
- QPainter painter(titleBar_pix);
+ TQPixmap* titleBar_pix = new TQPixmap(r.size());
+ TQPainter painter(titleBar_pix);
painter.drawTiledPixmap(0, 0, r.width(), r.height(), *titleBarPix);
int lw = buttonsLeftWidth()+3;
int rw = buttonsRightWidth();
painter.setFont(options()->font(true,false));
- QFontMetrics fm = painter.fontMetrics();
+ TQFontMetrics fm = painter.fontMetrics();
int captionWidth = fm.width(caption());
int titleWidth = titleBar->width()-(lw+rw);
- QRect re(titleWidth > captionWidth ? (titleWidth-captionWidth)/2+lw : lw, 0, titleWidth, r.height());
+ TQRect re(titleWidth > captionWidth ? (titleWidth-captionWidth)/2+lw : lw, 0, titleWidth, r.height());
painter.setClipRect(re);
painter.setPen(options()->color(KDecorationDefines::ColorFont, isActive()));
- painter.drawText(QRect(lw, r.y(), r.width()-(rw+lw), r.height()), titleWidth > captionWidth ? Qt::AlignCenter : Qt::AlignLeft|Qt::AlignVCenter, caption());
+ painter.drawText(TQRect(lw, r.y(), r.width()-(rw+lw), r.height()), titleWidth > captionWidth ? TQt::AlignCenter : TQt::AlignLeft|TQt::AlignVCenter, caption());
painter.end();
titleBar->setErasePixmap(*titleBar_pix);
@@ -931,10 +931,10 @@ void DominoClient::activeChange()
void DominoClient::iconChange()
{
if(menuButton) {
- QPixmap pix(*buttonHidePix);
- QPixmap icon = KDecoration::icon().pixmap(QIconSet::Small, QIconSet::Normal);
+ TQPixmap pix(*buttonHidePix);
+ TQPixmap icon = KDecoration::icon().pixmap(TQIconSet::Small, TQIconSet::Normal);
if(!icon.isNull())
- bitBlt(&pix, 0, 0, &icon, 0, 0, -1, -1, Qt::CopyROP);
+ bitBlt(&pix, 0, 0, &icon, 0, 0, -1, -1, TQt::CopyROP);
menuButton->setErasePixmap(pix);
}
@@ -982,7 +982,7 @@ void DominoClient::shadeChange()
}
-void DominoClient::resize( const QSize& s )
+void DominoClient::resize( const TQSize& s )
{
widget()->resize( s );
if(maximizeMode() == MaximizeFull && !options()->moveResizeMaximizedWindows()) {
@@ -1004,7 +1004,7 @@ void DominoClient::resize( const QSize& s )
}
-void DominoClient::resizeEvent( QResizeEvent* ev )
+void DominoClient::resizeEvent( TQResizeEvent* ev )
{
if (!Domino_initialized || ev->size() == ev->oldSize())
@@ -1018,45 +1018,45 @@ void DominoClient::updateWindowShape()
{
}
-void DominoClient::showEvent(QShowEvent *)
+void DominoClient::showEvent(TQShowEvent *)
{
}
-void DominoClient::paintEvent( QPaintEvent* )
+void DominoClient::paintEvent( TQPaintEvent* )
{
}
-bool DominoClient::eventFilter(QObject*, QEvent* e)
+bool DominoClient::eventFilter(TQObject*, TQEvent* e)
{
switch(e->type()) {
- case QEvent::Resize:
- resizeEvent(static_cast<QResizeEvent*>(e));
+ case TQEvent::Resize:
+ resizeEvent(static_cast<TQResizeEvent*>(e));
return true;
- case QEvent::ApplicationPaletteChange:
+ case TQEvent::ApplicationPaletteChange:
return false;
- case QEvent::Paint:
- paintEvent(static_cast<QPaintEvent*>(e));
+ case TQEvent::Paint:
+ paintEvent(static_cast<TQPaintEvent*>(e));
return true;
- case QEvent::MouseButtonDblClick:
- mouseDoubleClickEvent(static_cast<QMouseEvent*>(e));
+ case TQEvent::MouseButtonDblClick:
+ mouseDoubleClickEvent(static_cast<TQMouseEvent*>(e));
return true;
- case QEvent::Wheel:
+ case TQEvent::Wheel:
if(titleBar->hasMouse() || isSetShade())
- wheelEvent(static_cast<QWheelEvent*>(e));
+ wheelEvent(static_cast<TQWheelEvent*>(e));
return true;
- case QEvent::MouseButtonPress:
- processMousePressEvent(static_cast<QMouseEvent*>(e));
+ case TQEvent::MouseButtonPress:
+ processMousePressEvent(static_cast<TQMouseEvent*>(e));
return true;
- case QEvent::Show:
+ case TQEvent::Show:
return true;
- case QEvent::Enter:
+ case TQEvent::Enter:
updateButtons();
return true;
- case QEvent::Leave:
+ case TQEvent::Leave:
if(globalMouseTracking && !showInactiveButtons) {
globalMouseTracking = false;
- qApp->setGlobalMouseTracking( false );
- qApp->removeEventFilter(titleBar);
+ tqApp->setGlobalMouseTracking( false );
+ tqApp->removeEventFilter(titleBar);
titleBarMouseOver = false;
}
updateButtons();
@@ -1068,13 +1068,13 @@ bool DominoClient::eventFilter(QObject*, QEvent* e)
}
-void TitleBar::enterEvent(QEvent*)
+void TitleBar::enterEvent(TQEvent*)
{
if(!client->isActive() && !showInactiveButtons) {
if(!client->globalMouseTracking) {
client->globalMouseTracking = true;
- qApp->setGlobalMouseTracking( true );
- qApp->installEventFilter(this);
+ tqApp->setGlobalMouseTracking( true );
+ tqApp->installEventFilter(this);
client->titleBarMouseOver = true;
client->updateButtons();
}
@@ -1082,11 +1082,11 @@ void TitleBar::enterEvent(QEvent*)
}
-bool TitleBar::eventFilter(QObject*o, QEvent* e) {
+bool TitleBar::eventFilter(TQObject*o, TQEvent* e) {
- if(e->type() == QEvent::MouseMove && !showInactiveButtons && !client->isActive()) {
- QPoint pos = ((QMouseEvent*)e)->pos();
- if((dynamic_cast<QWidget*>(o) && geometry().contains(pos)) || dynamic_cast<QButton*>(o)) {
+ if(e->type() == TQEvent::MouseMove && !showInactiveButtons && !client->isActive()) {
+ TQPoint pos = ((TQMouseEvent*)e)->pos();
+ if((dynamic_cast<TQWidget*>(o) && geometry().contains(pos)) || dynamic_cast<TQButton*>(o)) {
client->titleBarMouseOver = true;
}
else {
@@ -1101,16 +1101,16 @@ bool TitleBar::eventFilter(QObject*o, QEvent* e) {
/////////////
-void renderGradient(QPainter *painter, QRect &rect,
- QColor &c1, QColor &c2, const char* /*name*/)
+void renderGradient(TQPainter *painter, TQRect &rect,
+ TQColor &c1, TQColor &c2, const char* /*name*/)
{
if((rect.width() <= 0)||(rect.height() <= 0))
return;
- QPixmap *result;
+ TQPixmap *result;
- result = new QPixmap(10, rect.height());
- QPainter p(result);
+ result = new TQPixmap(10, rect.height());
+ TQPainter p(result);
int r_h = result->rect().height();
int r_x, r_y, r_x2, r_y2;
@@ -1138,7 +1138,7 @@ void renderGradient(QPainter *painter, QRect &rect,
rl += rdelta;
gl += gdelta;
bl += bdelta;
- p.setPen(QColor(rl>>16, gl>>16, bl>>16));
+ p.setPen(TQColor(rl>>16, gl>>16, bl>>16));
p.drawLine(r_x, r_y+y, r_x2, r_y+y);
}
p.end();
@@ -1149,34 +1149,34 @@ void renderGradient(QPainter *painter, QRect &rect,
}
-QColor alphaBlendColors(const QColor &bgColor, const QColor &fgColor, const int a)
+TQColor alphaBlendColors(const TQColor &bgColor, const TQColor &fgColor, const int a)
{
- QRgb rgb = bgColor.rgb();
- QRgb rgb_b = fgColor.rgb();
+ TQRgb rgb = bgColor.rgb();
+ TQRgb rgb_b = fgColor.rgb();
int alpha = a;
if(alpha>255) alpha = 255;
if(alpha<0) alpha = 0;
int inv_alpha = 255 - alpha;
- QColor result = QColor( qRgb(qRed(rgb_b)*inv_alpha/255 + qRed(rgb)*alpha/255,
- qGreen(rgb_b)*inv_alpha/255 + qGreen(rgb)*alpha/255,
- qBlue(rgb_b)*inv_alpha/255 + qBlue(rgb)*alpha/255) );
+ TQColor result = TQColor( tqRgb(tqRed(rgb_b)*inv_alpha/255 + tqRed(rgb)*alpha/255,
+ tqGreen(rgb_b)*inv_alpha/255 + tqGreen(rgb)*alpha/255,
+ tqBlue(rgb_b)*inv_alpha/255 + tqBlue(rgb)*alpha/255) );
return result;
}
-QImage tintImage(const QImage &img, const QColor &tintColor) {
+TQImage tintImage(const TQImage &img, const TQColor &tintColor) {
- QImage *result = new QImage(img.width(), img.height(), 32, 0, QImage::IgnoreEndian);
+ TQImage *result = new TQImage(img.width(), img.height(), 32, 0, TQImage::IgnoreEndian);
unsigned int *data = (unsigned int*) img.bits();
unsigned int *resultData = (unsigned int*) result->bits();
result->setAlphaBuffer( true );
int alpha;
int total = img.width()*img.height();
for ( int current = 0 ; current < total ; ++current ) {
- alpha = qAlpha( data[ current ] );
- resultData[ current ] = qRgba( tintColor.red(), tintColor.green(), tintColor.blue(), alpha );
+ alpha = tqAlpha( data[ current ] );
+ resultData[ current ] = tqRgba( tintColor.red(), tintColor.green(), tintColor.blue(), alpha );
}
return *result;
}
diff --git a/client/dominoclient.h b/client/dominoclient.h
index 3c92495..0bb39be 100644
--- a/client/dominoclient.h
+++ b/client/dominoclient.h
@@ -25,14 +25,14 @@
#include <kcommondecoration.h>
#include <kdecorationfactory.h>
-#include <qlayout.h>
+#include <tqlayout.h>
namespace Domino {
class DominoClient;
class TitleBar;
-class DominoHandler: public QObject, public KDecorationFactory
+class DominoHandler: public TQObject, public KDecorationFactory
{
public:
DominoHandler();
@@ -41,16 +41,16 @@ class DominoHandler: public QObject, public KDecorationFactory
bool reset( unsigned long changed );
virtual bool supports( Ability ability );
- QColor buttonContourColor;
- QColor buttonMouseOverContourColor;
- QColor buttonPressedContourColor;
+ TQColor buttonContourColor;
+ TQColor buttonMouseOverContourColor;
+ TQColor buttonPressedContourColor;
bool customButtonColor;
- QColor buttonColor;
+ TQColor buttonColor;
bool customButtonIconColor;
- QColor buttonIconColor;
+ TQColor buttonIconColor;
bool customBorderColor;
- QColor borderColor;
+ TQColor borderColor;
bool darkLines;
private:
@@ -70,10 +70,10 @@ class DominoButton : public KCommonDecorationButton
void reset(unsigned long changed);
protected:
- void enterEvent(QEvent *);
- void leaveEvent(QEvent *);
- void drawButton(QPainter *p);
- void drawButtonLabel(QPainter*) {;}
+ void enterEvent(TQEvent *);
+ void leaveEvent(TQEvent *);
+ void drawButton(TQPainter *p);
+ void drawButtonLabel(TQPainter*) {;}
bool isMouseOver;
DominoClient* client;
@@ -87,9 +87,9 @@ class DominoClient : public KCommonDecoration
DominoClient( KDecorationBridge* b, KDecorationFactory* f );
~DominoClient();
- virtual QString visibleName() const;
- virtual QString defaultButtonsLeft() const;
- virtual QString defaultButtonsRight() const;
+ virtual TQString visibleName() const;
+ virtual TQString defaultButtonsLeft() const;
+ virtual TQString defaultButtonsRight() const;
virtual bool decorationBehaviour(DecorationBehaviour behaviour) const;
virtual int layoutMetric(LayoutMetric lm, bool respectWindowState = true, const KCommonDecorationButton * = 0) const;
virtual KCommonDecorationButton *createButton(ButtonType type);
@@ -97,7 +97,7 @@ class DominoClient : public KCommonDecoration
void init();
void reset( unsigned long changed );
- void resize( const QSize& s );
+ void resize( const TQSize& s );
void updateMask();
void updateWindowShape();
@@ -107,15 +107,15 @@ class DominoClient : public KCommonDecoration
void iconChange();
TitleBar* titleBar;
- QWidget* borderTopLeft;
- QWidget* borderTopRight;
- QWidget* borderBottomLeft;
- QWidget* borderBottomRight;
- QWidget* borderLeft;
- QWidget* borderRight;
- QWidget* borderBottom;
- QGridLayout* mainlayout;
- QButton* menuButton;
+ TQWidget* borderTopLeft;
+ TQWidget* borderTopRight;
+ TQWidget* borderBottomLeft;
+ TQWidget* borderBottomRight;
+ TQWidget* borderLeft;
+ TQWidget* borderRight;
+ TQWidget* borderBottom;
+ TQGridLayout* mainlayout;
+ TQButton* menuButton;
void setPixmaps();
bool titleBarMouseOver;
@@ -126,31 +126,31 @@ class DominoClient : public KCommonDecoration
void menuButtonDestroyed();
protected:
- bool eventFilter(QObject*, QEvent*);
- void paintEvent(QPaintEvent*);
- void resizeEvent(QResizeEvent*);
- void showEvent(QShowEvent*);
+ bool eventFilter(TQObject*, TQEvent*);
+ void paintEvent(TQPaintEvent*);
+ void resizeEvent(TQResizeEvent*);
+ void showEvent(TQShowEvent*);
private:
void createLayout();
};
-class TitleBar : public QWidget
+class TitleBar : public TQWidget
{
public:
- TitleBar(QWidget* parent=0, const char* name=0) : QWidget(parent, name) {}
- void enterEvent(QEvent * e);
- bool eventFilter(QObject*, QEvent*);
+ TitleBar(TQWidget* parent=0, const char* name=0) : TQWidget(parent, name) {}
+ void enterEvent(TQEvent * e);
+ bool eventFilter(TQObject*, TQEvent*);
DominoClient* client;
};
-void renderGradient(QPainter *painter, QRect &rect,
- QColor &c1, QColor &c2, const char* name = 0);
-QColor alphaBlendColors(const QColor &backgroundColor, const QColor &foregroundColor, const int alpha);
-QImage tintImage(const QImage &img, const QColor &tintColor);
+void renderGradient(TQPainter *painter, TQRect &rect,
+ TQColor &c1, TQColor &c2, const char* name = 0);
+TQColor alphaBlendColors(const TQColor &backgroundColor, const TQColor &foregroundColor, const int alpha);
+TQImage tintImage(const TQImage &img, const TQColor &tintColor);
}
#endif
diff --git a/client/config/config.cpp b/client/config/config.cpp
index d7648f0..482c1df 100644
--- a/client/config/config.cpp
+++ b/client/config/config.cpp
@@ -23,15 +23,15 @@
#include "config.h"
#include <kglobal.h>
#include <klocale.h>
-#include <qvbox.h>
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qgroupbox.h>
-#include <qsettings.h>
+#include <tqvbox.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqgroupbox.h>
+#include <tqsettings.h>
extern "C"
{
- KDE_EXPORT QObject* allocate_config( KConfig* config, QWidget* parent )
+ KDE_EXPORT TQObject* allocate_config( KConfig* config, TQWidget* parent )
{
return(new DominoConfig(config, parent));
}
@@ -40,81 +40,81 @@ extern "C"
// NOTE:
// 'config' is a pointer to the kwindecoration modules open kwin config,
// and is by default set to the "Style" group.
// 'parent' is the parent of the QObject, which is a VBox inside the
// Configure tab in kwindecoration
-DominoConfig::DominoConfig( KConfig* config, QWidget* parent )
- : QObject( parent )
+DominoConfig::DominoConfig( KConfig* config, TQWidget* parent )
+ : TQObject( parent )
{
conf = new KConfig("kwindominorc");
KGlobal::locale()->insertCatalogue("kwin_clients");
- vBox = new QVBox( parent );
+ vBox = new TQVBox( parent );
- customBorderColor = new QCheckBox( i18n("Custom border color"), vBox );
- QHBox *hbox1 = new QHBox(vBox);
- hbox1->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
+ customBorderColor = new TQCheckBox( i18n("Custom border color"), vBox );
+ TQHBox *hbox1 = new TQHBox(vBox);
+ hbox1->layout()->addItem(new TQSpacerItem(20, 0, TQSizePolicy::Fixed, TQSizePolicy::Minimum) );
borderColor = new KColorButton(hbox1);
- customButtonColor = new QCheckBox( i18n("Custom button color"), vBox );
- QHBox *hbox2 = new QHBox(vBox);
- hbox2->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
+ customButtonColor = new TQCheckBox( i18n("Custom button color"), vBox );
+ TQHBox *hbox2 = new TQHBox(vBox);
+ hbox2->layout()->addItem(new TQSpacerItem(20, 0, TQSizePolicy::Fixed, TQSizePolicy::Minimum) );
buttonColor = new KColorButton(hbox2);
- customButtonIconColor = new QCheckBox( i18n("Custom button icon color"), vBox );
- QHBox *hbox3 = new QHBox(vBox);
- hbox3->layout()->addItem(new QSpacerItem(20, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
+ customButtonIconColor = new TQCheckBox( i18n("Custom button icon color"), vBox );
+ TQHBox *hbox3 = new TQHBox(vBox);
+ hbox3->layout()->addItem(new TQSpacerItem(20, 0, TQSizePolicy::Fixed, TQSizePolicy::Minimum) );
buttonIconColor = new KColorButton(hbox3);
- customGradientColors = new QCheckBox( i18n("Custom gradient colors"), vBox);
- QHBox *hbox4 = new QHBox(vBox);
- hbox4->layout()->addItem(new QSpacerItem(22, 0, QSizePolicy::Fixed, QSizePolicy::Minimum) );
+ customGradientColors = new TQCheckBox( i18n("Custom gradient colors"), vBox);
+ TQHBox *hbox4 = new TQHBox(vBox);
+ hbox4->layout()->addItem(new TQSpacerItem(22, 0, TQSizePolicy::Fixed, TQSizePolicy::Minimum) );
- QVBox *vbox1 = new QVBox(hbox4);
- new QLabel( i18n("Top gradient color"), vbox1);
+ TQVBox *vbox1 = new TQVBox(hbox4);
+ new TQLabel( i18n("Top gradient color"), vbox1);
topGradientColor = new KColorButton(vbox1);
- new QLabel(i18n("Bottom gradient color"), vbox1);
+ new TQLabel(i18n("Bottom gradient color"), vbox1);
bottomGradientColor = new KColorButton(vbox1);
- showInactiveButtons = new QCheckBox( i18n("Show inactive buttons"), vBox );
- showButtonIcons = new QCheckBox( i18n("Show button icons"), vBox );
- darkFrame = new QCheckBox( i18n("Dark window frame"), vBox );
+ showInactiveButtons = new TQCheckBox( i18n("Show inactive buttons"), vBox );
+ showButtonIcons = new TQCheckBox( i18n("Show button icons"), vBox );
+ darkFrame = new TQCheckBox( i18n("Dark window frame"), vBox );
///////////////////////////////////////
- QGroupBox* colorGb = new QGroupBox(vBox);
+ TQGroupBox* colorGb = new TQGroupBox(vBox);
colorGb->setTitle(i18n("Button contour colors:"));
- colorGb->setColumnLayout(0, Qt::Vertical );
+ colorGb->setColumnLayout(0, TQt::Vertical );
colorGb->layout()->setSpacing( 6 );
colorGb->layout()->setMargin( 11 );
- QGridLayout* gbLayout = new QGridLayout( colorGb->layout(), 4, 2 );
- gbLayout->setAlignment( Qt::AlignTop );
+ TQGridLayout* gbLayout = new TQGridLayout( colorGb->layout(), 4, 2 );
+ gbLayout->setAlignment( TQt::AlignTop );
- QLabel* labelSC = new QLabel(i18n("Standard color:"), colorGb);
+ TQLabel* labelSC = new TQLabel(i18n("Standard color:"), colorGb);
buttonContourColor = new KColorButton(colorGb);
- buttonContourColor->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
- QLabel* labelMC = new QLabel(i18n("Mouseover color:"), colorGb);
+ buttonContourColor->setSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Minimum);
+ TQLabel* labelMC = new TQLabel(i18n("Mouseover color:"), colorGb);
buttonMouseOverContourColor = new KColorButton(colorGb);
- QLabel* labelPC = new QLabel(i18n("Pressed color:"), colorGb);
+ TQLabel* labelPC = new TQLabel(i18n("Pressed color:"), colorGb);
buttonPressedContourColor = new KColorButton(colorGb);
- useDominoStyleContourColors = new QCheckBox( i18n("Use domino style contour colors"), colorGb );
+ useDominoStyleContourColors = new TQCheckBox( i18n("Use domino style contour colors"), colorGb );
gbLayout->addMultiCellWidget(useDominoStyleContourColors, 0, 0, 0, 1);
gbLayout->addWidget(labelSC, 1, 0);
- gbLayout->addItem(new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Minimum) );
+ gbLayout->addItem(new TQSpacerItem(20, 0, TQSizePolicy::Minimum, TQSizePolicy::Minimum) );
gbLayout->addWidget(buttonContourColor, 1, 1);
gbLayout->addWidget(labelMC, 2, 0);
- gbLayout->addItem(new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Minimum) );
+ gbLayout->addItem(new TQSpacerItem(20, 0, TQSizePolicy::Minimum, TQSizePolicy::Minimum) );
gbLayout->addWidget(buttonMouseOverContourColor, 2, 1);
gbLayout->addWidget(labelPC, 3, 0);
- gbLayout->addItem(new QSpacerItem(20, 0, QSizePolicy::Minimum, QSizePolicy::Minimum) );
+ gbLayout->addItem(new TQSpacerItem(20, 0, TQSizePolicy::Minimum, TQSizePolicy::Minimum) );
gbLayout->addWidget(buttonPressedContourColor, 3, 1);
@@ -139,17 +139,17 @@ DominoConfig::DominoConfig( KConfig* config, QWidget* parent )
connect(customButtonIconColor, SIGNAL(toggled(bool)), buttonIconColor, SLOT(setEnabled(bool)));
connect(customGradientColors, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
- connect(topGradientColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
- connect(bottomGradientColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
+ connect(topGradientColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
+ connect(bottomGradientColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
connect(customBorderColor, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
- connect(borderColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
+ connect(borderColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
connect(customButtonColor, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
- connect(buttonColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
+ connect(buttonColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
connect(customButtonIconColor, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
- connect(buttonIconColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
+ connect(buttonIconColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
connect(showInactiveButtons, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
connect(showButtonIcons, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
@@ -157,9 +157,9 @@ DominoConfig::DominoConfig( KConfig* config, QWidget* parent )
connect(useDominoStyleContourColors, SIGNAL(clicked()), this, SLOT(loadButtonContourColors()));
connect(useDominoStyleContourColors, SIGNAL(clicked()), this, SLOT(slotSelectionChanged()));
- connect(buttonContourColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
- connect(buttonMouseOverContourColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
- connect(buttonPressedContourColor, SIGNAL(changed(const QColor&)), this, SLOT(slotSelectionChanged()));
+ connect(buttonContourColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
+ connect(buttonMouseOverContourColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
+ connect(buttonPressedContourColor, SIGNAL(changed(const TQColor&)), this, SLOT(slotSelectionChanged()));
// Make the widgets visible in kwindecoration valueChanged
@@ -245,7 +245,7 @@ void DominoConfig::save(KConfig*)
void DominoConfig::defaults()
{
- QColor background = vBox->paletteBackgroundColor();
+ TQColor background = vBox->paletteBackgroundColor();
customBorderColor->setChecked(true);
borderColor->setColor("#777B7F");
@@ -269,9 +269,9 @@ void DominoConfig::defaults()
void DominoConfig::loadButtonContourColors() {
- QColor background = vBox->paletteBackgroundColor();
+ TQColor background = vBox->paletteBackgroundColor();
if(useDominoStyleContourColors->isChecked()) {
- QSettings s;
+ TQSettings s;
buttonContourColor->setColor(s.readEntry("/domino/Settings/buttonContourColor", background.dark(250).name()));
buttonMouseOverContourColor->setColor(s.readEntry("/domino/Settings/buttonMouseOverContourColor", background.dark(250).name()));
buttonPressedContourColor->setColor(s.readEntry("/domino/Settings/buttonPressedContourColor", background.dark(250).name()));
@@ -40,81 +40,81 @@ extern "C"
// 'config' is a pointer to the kwindecoration modules open kwin config,
// and is by default set to the "Style" group.
-// 'parent' is the parent of the QObject, which is a VBox inside the
+// 'parent' is the parent of the TQObject, which is a VBox inside the
// Configure tab in kwindecoration